package com.ruoyi.map.service;

import com.ruoyi.map.domain.Model;

import java.util.List;

/**
 * <p>
 *  服务类
 * </p>
 *
 * @author wrh
 * @since 2023-07-03
 */
public interface IModelService {

    public Model selectModelById(Integer id);

    public List<Model> selectModelList(Model model);

    public int insertModel(Model model);

    public int updateModel(Model model);

    public int deleteModelByIds(Integer[] ids);

    public int deleteModelById(Integer id);

}
